@@ -18,7 +18,6 @@
  */
 
 #include "sysincludes.h"
-#include "msdos.h"
 #include "mtools.h"
 #include "buffer.h"
 
@@ -62,7 +61,7 @@ static size_t pos_to_next_full_cyl(Buffer_t *Buffer, mt_off_t pos) {
  * All errors are fatal.
  */
 
-static int _buf_flush(Buffer_t *Buffer)
+static int mt_buf_flush(Buffer_t *Buffer)
 {
 	ssize_t ret;
 
@@ -101,7 +100,7 @@ static int _buf_flush(Buffer_t *Buffer)
 
 static int invalidate_buffer(Buffer_t *Buffer, mt_off_t start)
 {
-	if(_buf_flush(Buffer) < 0)
+	if(mt_buf_flush(Buffer) < 0)
 		return -1;
 
 	/* start reading at the beginning of start's sector
@@ -238,7 +237,7 @@ static ssize_t buf_pwrite(Stream_t *Stream, char *buf,
 					return ret;
 				bytes_read = (size_t) ret;
 				if(bytes_read % This->sectorSize) {
-				  fprintf(stderr, "Weird: read size (%zd) not a multiple of sector size (%d)\n", bytes_read, (int) This->sectorSize);
+				  fprintf(stderr, "Weird: read size ("SSZF") not a multiple of sector size (%d)\n", bytes_read, (int) This->sectorSize);
 				    bytes_read -= bytes_read % This->sectorSize;
 				    if(bytes_read == 0) {
 					fprintf(stderr, "Nothing left\n");
@@ -324,7 +323,7 @@ static int buf_flush(Stream_t *Stream)
 
 	if (!This->ever_dirty)
 		return 0;
-	ret = _buf_flush(This);
+	ret = mt_buf_flush(This);
 	if(ret == 0)
 		This->ever_dirty = 0;
 	return ret;
